@@ -13,6 +13,11 @@ class RedisStreamConsumer(AbstractConsumer, RedisMixin):
     """
     BROKER_KIND = 12
     GROUP = 'funboost_group'
+    BROKER_EXCLUSIVE_CONFIG_KEYS = ['redis_host']
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.redis_host = self.broker_exclusive_config.get("redis_host")
 
     def start_consuming_message(self):
         redis_server_info_dict = self.redis_db_frame_version3.info()
