@@ -1,4 +1,6 @@
 ﻿from pathlib import Path
+
+from nb_filelock import FileLock
 from persistqueue import Queue
 import json
 from persistqueue.serializers import json as json_serializer
@@ -15,12 +17,15 @@ class TxtFileConsumer(AbstractConsumer, ):
     BROKER_KIND = 25
 
     def _shedual_task(self):
+        file_queue_path = str((Path(funboost_config_deafult.TXT_FILE_PATH) / self.queue_name).absolute())
+        file_lock = FileLock(Path(file_queue_path) / f'_funboost_txtfile_{self.queue_name}.lock')
         queue = Queue(str((Path(funboost_config_deafult.TXT_FILE_PATH) / self.queue_name).absolute()), autosave=True, serializer=json_serializer)
         while True:
-            item = queue.get()
-            self._print_message_get_from_broker('txt文件', item)
-            kw = {'body': json.loads(item), 'q': queue, 'item': item}
-            self._submit_task(kw)
+            with file_lock:
+                item = queue.get()
+                self._print_message_get_from_broker('txt文件', item)
+                kw = {'body': json.loads(item), 'q': queue, 'item': item}
+                self._submit_task(kw)
 
     def _confirm_consume(self, kw):
         pass
